@@ -8,25 +8,38 @@ from ..gui import GUI
 from ..toolkit import toolkit_object
 from ..window import Window
 
+GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
+no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
+
 ModalDialogTester = toolkit_object('util.modal_dialog_tester:ModalDialogTester')
 no_modal_dialog_tester = (ModalDialogTester.__name__ == 'Unimplemented')
 
 
-class TestAboutDialog(unittest.TestCase):
+@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
+class TestAboutDialog(unittest.TestCase, GuiTestAssistant):
 
     def setUp(self):
-        self.gui = GUI()
+        GuiTestAssistant.setUp(self)
         self.dialog = AboutDialog()
 
+    def tearDown(self):
+        if self.dialog.control is not None:
+            with self.delete_widget(self.dialog.control):
+                self.dialog.destroy()
+        self.dialog = None
+        GuiTestAssistant.tearDown(self)
+
     def test_create(self):
         # test that creation and destruction works as expected
         self.dialog._create()
-        self.gui.process_events()
+        self.event_loop()
         self.dialog.destroy()
+        self.event_loop()
 
     def test_destroy(self):
         # test that destroy works even when no control
         self.dialog.destroy()
+        self.event_loop()
 
     def test_create_parent(self):
         # test that creation and destruction works as expected with a parent
@@ -34,16 +47,13 @@ class TestAboutDialog(unittest.TestCase):
         self.dialog.parent = parent.control
         parent._create()
         self.dialog._create()
-        self.gui.process_events()
-        self.dialog.destroy()
-        parent.destroy()
+        self.event_loop()
 
-    def test_create_ok_renamed(self):
-        # test that creation and destruction works as expected with ok_label
-        self.dialog.ok_label = "Sure"
-        self.dialog._create()
-        self.gui.process_events()
-        self.dialog.destroy()
+        with self.delete_widget(self.dialog.control):
+            self.dialog.destroy()
+        with self.delete_widget(parent.control):
+            parent.destroy()
+        self.event_loop()
 
     @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
     def test_accept(self):
@@ -63,23 +73,6 @@ class TestAboutDialog(unittest.TestCase):
         self.assertEqual(tester.result, CANCEL)
         self.assertEqual(self.dialog.return_code, CANCEL)
 
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
-    def test_ok(self):
-        # test that OK works as expected
-        tester = ModalDialogTester(self.dialog.open)
-        tester.open_and_wait(when_opened=lambda x: x.click_button(OK))
-        self.assertEqual(tester.result, OK)
-        self.assertEqual(self.dialog.return_code, OK)
-
-    @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
-    def test_renamed_ok(self):
-        self.dialog.ok_label = "Sure"
-        # test that OK works as expected if renamed
-        tester = ModalDialogTester(self.dialog.open)
-        tester.open_and_wait(when_opened=lambda x: x.click_widget("Sure"))
-        self.assertEqual(tester.result, OK)
-        self.assertEqual(self.dialog.return_code, OK)
-
     @unittest.skipIf(no_modal_dialog_tester, 'ModalDialogTester unavailable')
     def test_parent(self):
         # test that lifecycle works with a parent
@@ -89,5 +82,7 @@ class TestAboutDialog(unittest.TestCase):
         tester = ModalDialogTester(self.dialog.open)
         tester.open_and_run(when_opened=lambda x: x.close(accept=True))
         parent.close()
+        self.event_loop()
+
         self.assertEqual(tester.result, OK)
         self.assertEqual(self.dialog.return_code, OK)
