@@ -2,52 +2,66 @@
 
 from traits.testing.unittest_tools import unittest
 
-from ..constant import CANCEL
-from ..gui import GUI
 from ..progress_dialog import ProgressDialog
 from ..toolkit import toolkit_object
 
+GuiTestAssistant = toolkit_object('util.gui_test_assistant:GuiTestAssistant')
+no_gui_test_assistant = (GuiTestAssistant.__name__ == 'Unimplemented')
+
 ModalDialogTester = toolkit_object('util.modal_dialog_tester:ModalDialogTester')
 no_modal_dialog_tester = (ModalDialogTester.__name__ == 'Unimplemented')
 
 
-class TestDialog(unittest.TestCase):
+@unittest.skipIf(no_gui_test_assistant, 'No GuiTestAssistant')
+class TestProgressDialog(unittest.TestCase, GuiTestAssistant):
 
     def setUp(self):
-        self.gui = GUI()
+        GuiTestAssistant.setUp(self)
         self.dialog = ProgressDialog()
 
+    def tearDown(self):
+        if self.dialog.control is not None:
+            with self.delete_widget(self.dialog.control):
+                self.dialog.destroy()
+        del self.dialog
+        GuiTestAssistant.tearDown(self)
+
     def test_create(self):
         # test that creation and destruction works as expected
         self.dialog._create()
-        self.gui.process_events()
+        self.event_loop()
         self.dialog.destroy()
+        self.event_loop()
 
     def test_destroy(self):
         # test that destroy works even when no control
         self.dialog.destroy()
+        self.event_loop()
 
     def test_can_cancel(self):
         # test that creation works with can_cancel
         self.dialog.can_cancel =  True
         self.dialog._create()
-        self.gui.process_events()
+        self.event_loop()
         self.dialog.destroy()
+        self.event_loop()
 
     def test_show_time(self):
         # test that creation works with show_time
         self.dialog.show_time =  True
         self.dialog._create()
-        self.gui.process_events()
+        self.event_loop()
         self.dialog.destroy()
+        self.event_loop()
 
     @unittest.skip("not implemented in any backend")
     def test_show_percent(self):
         # test that creation works with show_percent
         self.dialog.show_percent =  True
         self.dialog._create()
-        self.gui.process_events()
+        self.event_loop()
         self.dialog.destroy()
+        self.event_loop()
 
     def test_update(self):
         self.dialog.min = 0
@@ -55,8 +69,9 @@ class TestDialog(unittest.TestCase):
         self.dialog.open()
         for i in range(11):
             result = self.dialog.update(i)
-            self.gui.process_events()
+            self.event_loop()
             self.assertEqual(result, (True, False))
+
         self.assertIsNone(self.dialog.control)
 
     @unittest.skip("inconsistent implementations")
@@ -73,10 +88,12 @@ class TestDialog(unittest.TestCase):
         self.dialog.open()
         for i in range(5):
             result = self.dialog.update(i)
-            self.gui.process_events()
+            self.event_loop()
             self.assertEqual(result, (True, False))
         self.assertIsNotNone(self.dialog.control)
         self.dialog.close()
+        self.event_loop()
+
         self.assertIsNone(self.dialog.control)
 
     def test_change_message(self):
@@ -86,7 +103,7 @@ class TestDialog(unittest.TestCase):
         for i in range(11):
             self.dialog.change_message('Updating {}'.format(i))
             result = self.dialog.update(i)
-            self.gui.process_events()
+            self.event_loop()
             self.assertEqual(result, (True, False))
             self.assertEqual(self.dialog.message, 'Updating {}'.format(i))
         self.assertIsNone(self.dialog.control)
@@ -98,7 +115,7 @@ class TestDialog(unittest.TestCase):
         self.dialog.open()
         for i in range(11):
             result = self.dialog.update(i)
-            self.gui.process_events()
+            self.event_loop()
             self.assertEqual(result, (True, False))
         self.assertIsNone(self.dialog.control)
 
@@ -108,18 +125,17 @@ class TestDialog(unittest.TestCase):
         self.dialog.open()
         for i in range(10):
             result = self.dialog.update(i)
-            self.gui.process_events()
+            self.event_loop()
             self.assertEqual(result, (True, False))
         self.dialog.close()
+        self.event_loop()
         # XXX not really sure what correct behaviour is here
 
     def test_update_negative(self):
         self.dialog.min = 0
         self.dialog.max = -10
-        self.dialog.open()
-        for i in range(11):
-            result = self.dialog.update(1)
-            self.gui.process_events()
-            self.assertEqual(result, (True, False))
-        self.dialog.close()
+        with self.assertRaises(AttributeError):
+            self.dialog.open()
+            self.event_loop()
+
         self.assertIsNone(self.dialog.control)
