@@ -116,7 +116,7 @@ class PythonShell(MPythonShell, Widget):
                 self.control.clearCommand()
                 self.control.write('# Executing "%s"\n' % path)
 
-            exec(compile(open(path).read(), path, 'exec'), prog_ns, prog_ns)
+            exec(compile(open(path, "rb").read(), path, 'exec'), prog_ns, prog_ns)
 
             if not hidden:
                 self.control.prompt()
